# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pihello']

package_data = \
{'': ['*']}

entry_points = \
{'console_scripts': ['pihello = pihello.cli:main']}

setup_kwargs = {
    'name': 'pihello',
    'version': '0.3.0',
    'description': 'Highly configurable and scriptable Pi-hole statistics in text',
    'long_description': '<div align="center">\n  <h1>pihello</h1>\n  <p>\n    <b>pihello</b> is a <u>simple</u> and <u>configurable</u>\n    command-line tool used to display statistics of your Pi-hole.\n    <br>\n    <i>No additional dependencies required.</i>\n  </p>\n  <a href="https://pypi.org/project/pihello/">\n    <img alt="PyPI" src="https://img.shields.io/pypi/v/pihello">\n  </a>\n  <img alt="PyPI - Python Version" src="https://img.shields.io/pypi/pyversions/pihello">\n  <img alt="PyPI - Wheel" src="https://img.shields.io/pypi/wheel/pihello">\n  <img alt="PyPI - License" src="https://img.shields.io/pypi/l/pihello">\n  <a href="https://github.com/pavelgar/pihello#development">\n    <img alt="PRs welcome!" src="https://img.shields.io/badge/PRs-welcome!-green">\n  </a>\n  <p></p>\n  <img src="docs/example_output.svg">\n</div>\n\n## What\'s this used for?\n\nYou frequently work in the terminal or ssh into your pi-hole host? Wouldn\'t it be nice to have a useful greeting message?\n\nJust install and add the `pihello <your.pihole.address> <your.pihole.api-token>` command to your shell\'s startup script (`.bash_profile`, `.zshenv`, `fish_greeting.fish`, etc.). Next time you open the terminal you\'ll be greeted by the default _(or your own)_ fancy message!\n\n## Installation\n\n### Requirements\n\n- A running [pi-hole](https://pi-hole.net/) instance\n- [Python >=3.8](https://www.python.org/downloads/)\n\n### Quickstart\n\nInstall:\n\n```\npip install pihello\n```\n\nRun a preconfigured display (as seen above):\n\n```\npihello <your.pihole.address> <your.pihole.api-token>\n```\n\n## Usage\n\n### Examples\n\nTo run from the command line for standard HTTP Pi-hole installs:\n\n```\npihello <your.pihole.address> <your.pihole.api-token>\n```\n\nTo run from the command line with a custom configuration file:\n\n```\npihello <your.pihole.address> <your.pihole.api-token> -f /path/to/config.txt\n```\n\nTo run from the command line for HTTPS Pi-hole installs:\n\n```\npihello <your.pihole.address> <your.pihole.api-token> -p\n```\n\nTo run from the command line for HTTPS Pi-hole installs w/custom path to pihole (e.g. `/pihole` instead of the default `/admin`) :\n\n```\npihello <your.pihole.address> <your.pihole.api-token> -p -u /pihole\n```\n\nFull command options:\n\n```\n$ pihello -h\nusage: pihello [-h] [-v] [-i INDENT] [-f FILE] [-c] [-W WIDTH] [-H HEIGHT] [-ts [TIMESTAMP]] [-p] [-u URI] addr token\n\npositional arguments:\n  addr                  the address of your Pi-hole\n  token                 your Pi-hole API Token from settings\n\noptional arguments:\n  -h, --help            show this help message and exit\n  -v, --version         show program\'s version number and exit\n  -i INDENT, --indent INDENT\n                        set the indentation step (default: 4)\n  -f FILE, --file FILE  specify path to the output config file\n  -c, --clip            set whether overflowing text will be discarded or added to the next line\n  -W WIDTH, --width WIDTH\n                        set the screen width (0 = no limit). (default: 80)\n  -H HEIGHT, --height HEIGHT\n                        set the screen height (0 = no limit). (default: 25)\n  -ts [TIMESTAMP], --timestamp [TIMESTAMP]\n                        add a timestamp as the first line. Pass optional strftime format string. Example "%H:%M - %a %d/%m/%y"\n  -p, --proto           use HTTPS instead of HTTP.\n  -u URI, --uri URI     set a different path (URI) for pihole. (default: /admin)\n```\n\n### Configuration\n\nCreate a configuration text file anywhere in your userspace.\n\n**[example.txt](docs/example.txt)**\n\n> More example configurations can be found in [docs/SHOWCASE.md](docs/SHOWCASE.md).\n\n```\n[cyan2]─────────────────────────────────────────────────────[]\n[white]PiHole[] ([green4]{status}[]) [lightgreen]{core_current}[white], Web [lightgreen]{web_current}[white], FTL [lightgreen]{FTL_current}\n[cyan2]─────────────────────────────────────────────────────[]\nBlocking [darkcyan]{domains_being_blocked}[] domains for [steelblue]{unique_clients}[] clients\nBlocked [fuchsia]{ads_blocked_today}[] out of [lightgreen]{dns_queries_today}[] queries [underline]today[] ([steelblue]{ads_percentage_today}%[])\n[grey37]Gravity last updated [bold grey50]{gravity_last_updated.relative.days}[grey37] days [bold grey50]{gravity_last_updated.relative.hours}[grey37] hours and [bold grey50]{gravity_last_updated.relative.minutes}[grey37] minutes ago\n```\n\nRun `pihello` with the `-f` flag pointing to the configuration file:\n\n```\npihello <your.pihole.address> <your.pihole.api-token> -f /home/username/path_to/example.txt\n```\n\n### Variable injection\n\nPiHole API\'s variables can be easily injected by using curly braces `{ }`.\n\n**Syntax**: `{variable_name}`\n\n**Example:** `"PiHole {core_current} (FTL: {FTL_current})"`\n\n**Notes:**\n\n- Variable names are case-sensitive\n- Open curly brace, which is not part of a variable injection, should be escaped like so `\\{`\n\n<details>\n<summary><b>Available variables</b></summary>\n\n| Key                                     |              Example value | Type  |\n| :-------------------------------------- | -------------------------: | :---: |\n| `recent_blocked`                        | `ssl.google-analytics.com` |  str  |\n| `core_update`                           |                    `False` | bool  |\n| `web_update`                            |                    `False` | bool  |\n| `FTL_update`                            |                    `False` | bool  |\n| `core_current`                          |                   `v5.1.2` |  str  |\n| `web_current`                           |                   `v5.1.1` |  str  |\n| `FTL_current`                           |                     `v5.2` |  str  |\n| `core_latest`                           |                   `v5.1.2` |  str  |\n| `web_latest`                            |                   `v5.1.1` |  str  |\n| `FTL_latest`                            |                     `v5.2` |  str  |\n| `core_branch`                           |                   `master` |  str  |\n| `web_branch`                            |                   `master` |  str  |\n| `FTL_branch`                            |                   `master` |  str  |\n| `domains_being_blocked`                 |                    `94541` |  int  |\n| `dns_queries_today`                     |                    `14324` |  int  |\n| `ads_blocked_today`                     |                     `3917` |  int  |\n| `ads_percentage_today`                  |                `27.345713` | float |\n| `unique_domains`                        |                     `5967` |  int  |\n| `queries_forwarded`                     |                     `7942` |  int  |\n| `queries_cached`                        |                     `2465` |  int  |\n| `clients_ever_seen`                     |                       `12` |  int  |\n| `unique_clients`                        |                        `9` |  int  |\n| `dns_queries_all_types`                 |                    `14324` |  int  |\n| `reply_NODATA`                          |                      `423` |  int  |\n| `reply_NXDOMAIN`                        |                      `223` |  int  |\n| `reply_CNAME`                           |                     `3784` |  int  |\n| `reply_IP`                              |                     `8768` |  int  |\n| `privacy_level`                         |                        `0` |  int  |\n| `status`                                |                  `enabled` |  str  |\n| `gravity_last_updated.file_exists`      |                     `True` | bool  |\n| `gravity_last_updated.absolute`         |               `1602374786` |  int  |\n| `gravity_last_updated.relative.days`    |                        `1` |  int  |\n| `gravity_last_updated.relative.hours`   |                       `12` |  int  |\n| `gravity_last_updated.relative.minutes` |                       `29` |  int  |\n\n</details>\n\n### Styling\n\n- Text styling is done by inserting style tags `[ ]`\n- Color prepended by a semicolon `:` indicates a **background color**\n- Color prepended by an underline `_` indicates an **underlined color**\n  _AFAIK, only supported in Kitty, VTE, mintty and iTerm2._\n\n**Syntax:** `[<style> <foreground_color> :<background_color> _<underline_color>]`\n\n**Example:** `"[italic navy]Hello [underline maroon :green]World[bold]!"`\n\n**Notes:**\n\n- Open square bracket, which is not part of a style, must be escaped like so `\\[`\n- Empty square brackets, `[]`, can be used to reset the style\n- Order of the parameters does not matter\n- Extra whitespace and letter\'s case is ignored\n\n<details>\n<summary><b>Available styles</b></summary>\n\n| Style            | Format string | Notes                            |\n| :--------------- | :-----------: | :------------------------------- |\n| Normal           |   `normal`    | Reset the font to normal.        |\n| Bold             |    `bold`     |                                  |\n| Faint            |    `faint`    |                                  |\n| Italic           |   `italic`    |                                  |\n| Underline        |  `underline`  |                                  |\n| Double underline | `dunderline`  | Usually just a single underline. |\n| Blink            |    `blink`    | Usually not supported.           |\n| Fast blink       |   `fblink`    | Usually not supported.           |\n| Strikethrough    |   `strike`    | Usually not supported.           |\n\n</details>\n\n#### Colors\n\nThere is a number of ways to define a color:\n\n| Definition                                                           | Matching regex        |        Example | Notes                                                                               |\n| :------------------------------------------------------------------- | :-------------------- | -------------: | :---------------------------------------------------------------------------------- |\n| Color name                                                           | `[0-9a-z]+`           |        `black` | Preferred way to define a color.                                                    |\n| [Color number](https://en.wikipedia.org/wiki/ANSI_escape_code#8-bit) | `color\\([0-9]{1,3}\\)` |     `color(0)` | Good way to ensure compatibility with<br>old or simple terminal emulators/displays. |\n| Hex value                                                            | `\\#[0-9a-f]{6}`       |      `#000000` |                                                                                     |\n| RGB values                                                           | `rgb\\([\\d\\s,]+\\)`     | `rgb(0, 0, 0)` |                                                                                     |\n\n<details>\n<summary><b>Available color names</b></summary>\n\nThese are [Xterm](https://jonasjacek.github.io/colors/) color names.\nDuplicate color names have been removed keeping the last (usually brightest) occurence.\nThis list has currently 202 rows.\n\n| Color # | Color name          |    HEX    |        RGB         |\n| :-----: | :------------------ | :-------: | :----------------: |\n|    0    | `black`             | `#000000` |    `rgb(0,0,0)`    |\n|    1    | `maroon`            | `#800000` |   `rgb(128,0,0)`   |\n|    2    | `green`             | `#008000` |   `rgb(0,128,0)`   |\n|    3    | `olive`             | `#808000` |  `rgb(128,128,0)`  |\n|    4    | `navy`              | `#000080` |   `rgb(0,0,128)`   |\n|    6    | `teal`              | `#008080` |  `rgb(0,128,128)`  |\n|    7    | `silver`            | `#c0c0c0` | `rgb(192,192,192)` |\n|    8    | `grey`              | `#808080` | `rgb(128,128,128)` |\n|    9    | `red`               | `#ff0000` |   `rgb(255,0,0)`   |\n|   10    | `lime`              | `#00ff00` |   `rgb(0,255,0)`   |\n|   11    | `yellow`            | `#ffff00` |  `rgb(255,255,0)`  |\n|   12    | `blue`              | `#0000ff` |   `rgb(0,0,255)`   |\n|   13    | `fuchsia`           | `#ff00ff` |  `rgb(255,0,255)`  |\n|   14    | `aqua`              | `#00ffff` |  `rgb(0,255,255)`  |\n|   15    | `white`             | `#ffffff` | `rgb(255,255,255)` |\n|   16    | `grey0`             | `#000000` |    `rgb(0,0,0)`    |\n|   17    | `navyblue`          | `#00005f` |   `rgb(0,0,95)`    |\n|   18    | `darkblue`          | `#000087` |   `rgb(0,0,135)`   |\n|   20    | `blue3`             | `#0000d7` |   `rgb(0,0,215)`   |\n|   21    | `blue1`             | `#0000ff` |   `rgb(0,0,255)`   |\n|   22    | `darkgreen`         | `#005f00` |   `rgb(0,95,0)`    |\n|   25    | `deepskyblue4`      | `#005faf` |  `rgb(0,95,175)`   |\n|   26    | `dodgerblue3`       | `#005fd7` |  `rgb(0,95,215)`   |\n|   27    | `dodgerblue2`       | `#005fff` |  `rgb(0,95,255)`   |\n|   28    | `green4`            | `#008700` |   `rgb(0,135,0)`   |\n|   29    | `springgreen4`      | `#00875f` |  `rgb(0,135,95)`   |\n|   30    | `turquoise4`        | `#008787` |  `rgb(0,135,135)`  |\n|   32    | `deepskyblue3`      | `#0087d7` |  `rgb(0,135,215)`  |\n|   33    | `dodgerblue1`       | `#0087ff` |  `rgb(0,135,255)`  |\n|   36    | `darkcyan`          | `#00af87` |  `rgb(0,175,135)`  |\n|   37    | `lightseagreen`     | `#00afaf` |  `rgb(0,175,175)`  |\n|   38    | `deepskyblue2`      | `#00afd7` |  `rgb(0,175,215)`  |\n|   39    | `deepskyblue1`      | `#00afff` |  `rgb(0,175,255)`  |\n|   40    | `green3`            | `#00d700` |   `rgb(0,215,0)`   |\n|   41    | `springgreen3`      | `#00d75f` |  `rgb(0,215,95)`   |\n|   43    | `cyan3`             | `#00d7af` |  `rgb(0,215,175)`  |\n|   44    | `darkturquoise`     | `#00d7d7` |  `rgb(0,215,215)`  |\n|   45    | `turquoise2`        | `#00d7ff` |  `rgb(0,215,255)`  |\n|   46    | `green1`            | `#00ff00` |   `rgb(0,255,0)`   |\n|   47    | `springgreen2`      | `#00ff5f` |  `rgb(0,255,95)`   |\n|   48    | `springgreen1`      | `#00ff87` |  `rgb(0,255,135)`  |\n|   49    | `mediumspringgreen` | `#00ffaf` |  `rgb(0,255,175)`  |\n|   50    | `cyan2`             | `#00ffd7` |  `rgb(0,255,215)`  |\n|   51    | `cyan1`             | `#00ffff` |  `rgb(0,255,255)`  |\n|   55    | `purple4`           | `#5f00af` |  `rgb(95,0,175)`   |\n|   56    | `purple3`           | `#5f00d7` |  `rgb(95,0,215)`   |\n|   57    | `blueviolet`        | `#5f00ff` |  `rgb(95,0,255)`   |\n|   59    | `grey37`            | `#5f5f5f` |  `rgb(95,95,95)`   |\n|   60    | `mediumpurple4`     | `#5f5f87` |  `rgb(95,95,135)`  |\n|   62    | `slateblue3`        | `#5f5fd7` |  `rgb(95,95,215)`  |\n|   63    | `royalblue1`        | `#5f5fff` |  `rgb(95,95,255)`  |\n|   64    | `chartreuse4`       | `#5f8700` |  `rgb(95,135,0)`   |\n|   66    | `paleturquoise4`    | `#5f8787` | `rgb(95,135,135)`  |\n|   67    | `steelblue`         | `#5f87af` | `rgb(95,135,175)`  |\n|   68    | `steelblue3`        | `#5f87d7` | `rgb(95,135,215)`  |\n|   69    | `cornflowerblue`    | `#5f87ff` | `rgb(95,135,255)`  |\n|   71    | `darkseagreen4`     | `#5faf5f` |  `rgb(95,175,95)`  |\n|   73    | `cadetblue`         | `#5fafaf` | `rgb(95,175,175)`  |\n|   74    | `skyblue3`          | `#5fafd7` | `rgb(95,175,215)`  |\n|   76    | `chartreuse3`       | `#5fd700` |  `rgb(95,215,0)`   |\n|   78    | `seagreen3`         | `#5fd787` | `rgb(95,215,135)`  |\n|   79    | `aquamarine3`       | `#5fd7af` | `rgb(95,215,175)`  |\n|   80    | `mediumturquoise`   | `#5fd7d7` | `rgb(95,215,215)`  |\n|   81    | `steelblue1`        | `#5fd7ff` | `rgb(95,215,255)`  |\n|   83    | `seagreen2`         | `#5fff5f` |  `rgb(95,255,95)`  |\n|   85    | `seagreen1`         | `#5fffaf` | `rgb(95,255,175)`  |\n|   87    | `darkslategray2`    | `#5fffff` | `rgb(95,255,255)`  |\n|   88    | `darkred`           | `#870000` |   `rgb(135,0,0)`   |\n|   91    | `darkmagenta`       | `#8700af` |  `rgb(135,0,175)`  |\n|   94    | `orange4`           | `#875f00` |  `rgb(135,95,0)`   |\n|   95    | `lightpink4`        | `#875f5f` |  `rgb(135,95,95)`  |\n|   96    | `plum4`             | `#875f87` | `rgb(135,95,135)`  |\n|   98    | `mediumpurple3`     | `#875fd7` | `rgb(135,95,215)`  |\n|   99    | `slateblue1`        | `#875fff` | `rgb(135,95,255)`  |\n|   101   | `wheat4`            | `#87875f` | `rgb(135,135,95)`  |\n|   102   | `grey53`            | `#878787` | `rgb(135,135,135)` |\n|   103   | `lightslategrey`    | `#8787af` | `rgb(135,135,175)` |\n|   104   | `mediumpurple`      | `#8787d7` | `rgb(135,135,215)` |\n|   105   | `lightslateblue`    | `#8787ff` | `rgb(135,135,255)` |\n|   106   | `yellow4`           | `#87af00` |  `rgb(135,175,0)`  |\n|   108   | `darkseagreen`      | `#87af87` | `rgb(135,175,135)` |\n|   110   | `lightskyblue3`     | `#87afd7` | `rgb(135,175,215)` |\n|   111   | `skyblue2`          | `#87afff` | `rgb(135,175,255)` |\n|   112   | `chartreuse2`       | `#87d700` |  `rgb(135,215,0)`  |\n|   114   | `palegreen3`        | `#87d787` | `rgb(135,215,135)` |\n|   116   | `darkslategray3`    | `#87d7d7` | `rgb(135,215,215)` |\n|   117   | `skyblue1`          | `#87d7ff` | `rgb(135,215,255)` |\n|   118   | `chartreuse1`       | `#87ff00` |  `rgb(135,255,0)`  |\n|   120   | `lightgreen`        | `#87ff87` | `rgb(135,255,135)` |\n|   122   | `aquamarine1`       | `#87ffd7` | `rgb(135,255,215)` |\n|   123   | `darkslategray1`    | `#87ffff` | `rgb(135,255,255)` |\n|   125   | `deeppink4`         | `#af005f` |  `rgb(175,0,95)`   |\n|   126   | `mediumvioletred`   | `#af0087` |  `rgb(175,0,135)`  |\n|   128   | `darkviolet`        | `#af00d7` |  `rgb(175,0,215)`  |\n|   129   | `purple`            | `#af00ff` |  `rgb(175,0,255)`  |\n|   133   | `mediumorchid3`     | `#af5faf` | `rgb(175,95,175)`  |\n|   134   | `mediumorchid`      | `#af5fd7` | `rgb(175,95,215)`  |\n|   136   | `darkgoldenrod`     | `#af8700` |  `rgb(175,135,0)`  |\n|   138   | `rosybrown`         | `#af8787` | `rgb(175,135,135)` |\n|   139   | `grey63`            | `#af87af` | `rgb(175,135,175)` |\n|   140   | `mediumpurple2`     | `#af87d7` | `rgb(175,135,215)` |\n|   141   | `mediumpurple1`     | `#af87ff` | `rgb(175,135,255)` |\n|   143   | `darkkhaki`         | `#afaf5f` | `rgb(175,175,95)`  |\n|   144   | `navajowhite3`      | `#afaf87` | `rgb(175,175,135)` |\n|   145   | `grey69`            | `#afafaf` | `rgb(175,175,175)` |\n|   146   | `lightsteelblue3`   | `#afafd7` | `rgb(175,175,215)` |\n|   147   | `lightsteelblue`    | `#afafff` | `rgb(175,175,255)` |\n|   149   | `darkolivegreen3`   | `#afd75f` | `rgb(175,215,95)`  |\n|   150   | `darkseagreen3`     | `#afd787` | `rgb(175,215,135)` |\n|   152   | `lightcyan3`        | `#afd7d7` | `rgb(175,215,215)` |\n|   153   | `lightskyblue1`     | `#afd7ff` | `rgb(175,215,255)` |\n|   154   | `greenyellow`       | `#afff00` |  `rgb(175,255,0)`  |\n|   155   | `darkolivegreen2`   | `#afff5f` | `rgb(175,255,95)`  |\n|   156   | `palegreen1`        | `#afff87` | `rgb(175,255,135)` |\n|   157   | `darkseagreen2`     | `#afffaf` | `rgb(175,255,175)` |\n|   159   | `paleturquoise1`    | `#afffff` | `rgb(175,255,255)` |\n|   160   | `red3`              | `#d70000` |   `rgb(215,0,0)`   |\n|   162   | `deeppink3`         | `#d70087` |  `rgb(215,0,135)`  |\n|   164   | `magenta3`          | `#d700d7` |  `rgb(215,0,215)`  |\n|   166   | `darkorange3`       | `#d75f00` |  `rgb(215,95,0)`   |\n|   167   | `indianred`         | `#d75f5f` |  `rgb(215,95,95)`  |\n|   168   | `hotpink3`          | `#d75f87` | `rgb(215,95,135)`  |\n|   169   | `hotpink2`          | `#d75faf` | `rgb(215,95,175)`  |\n|   170   | `orchid`            | `#d75fd7` | `rgb(215,95,215)`  |\n|   172   | `orange3`           | `#d78700` |  `rgb(215,135,0)`  |\n|   173   | `lightsalmon3`      | `#d7875f` | `rgb(215,135,95)`  |\n|   174   | `lightpink3`        | `#d78787` | `rgb(215,135,135)` |\n|   175   | `pink3`             | `#d787af` | `rgb(215,135,175)` |\n|   176   | `plum3`             | `#d787d7` | `rgb(215,135,215)` |\n|   177   | `violet`            | `#d787ff` | `rgb(215,135,255)` |\n|   178   | `gold3`             | `#d7af00` |  `rgb(215,175,0)`  |\n|   179   | `lightgoldenrod3`   | `#d7af5f` | `rgb(215,175,95)`  |\n|   180   | `tan`               | `#d7af87` | `rgb(215,175,135)` |\n|   181   | `mistyrose3`        | `#d7afaf` | `rgb(215,175,175)` |\n|   182   | `thistle3`          | `#d7afd7` | `rgb(215,175,215)` |\n|   183   | `plum2`             | `#d7afff` | `rgb(215,175,255)` |\n|   184   | `yellow3`           | `#d7d700` |  `rgb(215,215,0)`  |\n|   185   | `khaki3`            | `#d7d75f` | `rgb(215,215,95)`  |\n|   187   | `lightyellow3`      | `#d7d7af` | `rgb(215,215,175)` |\n|   188   | `grey84`            | `#d7d7d7` | `rgb(215,215,215)` |\n|   189   | `lightsteelblue1`   | `#d7d7ff` | `rgb(215,215,255)` |\n|   190   | `yellow2`           | `#d7ff00` |  `rgb(215,255,0)`  |\n|   192   | `darkolivegreen1`   | `#d7ff87` | `rgb(215,255,135)` |\n|   193   | `darkseagreen1`     | `#d7ffaf` | `rgb(215,255,175)` |\n|   194   | `honeydew2`         | `#d7ffd7` | `rgb(215,255,215)` |\n|   195   | `lightcyan1`        | `#d7ffff` | `rgb(215,255,255)` |\n|   196   | `red1`              | `#ff0000` |   `rgb(255,0,0)`   |\n|   197   | `deeppink2`         | `#ff005f` |  `rgb(255,0,95)`   |\n|   199   | `deeppink1`         | `#ff00af` |  `rgb(255,0,175)`  |\n|   200   | `magenta2`          | `#ff00d7` |  `rgb(255,0,215)`  |\n|   201   | `magenta1`          | `#ff00ff` |  `rgb(255,0,255)`  |\n|   202   | `orangered1`        | `#ff5f00` |  `rgb(255,95,0)`   |\n|   204   | `indianred1`        | `#ff5f87` | `rgb(255,95,135)`  |\n|   206   | `hotpink`           | `#ff5fd7` | `rgb(255,95,215)`  |\n|   207   | `mediumorchid1`     | `#ff5fff` | `rgb(255,95,255)`  |\n|   208   | `darkorange`        | `#ff8700` |  `rgb(255,135,0)`  |\n|   209   | `salmon1`           | `#ff875f` | `rgb(255,135,95)`  |\n|   210   | `lightcoral`        | `#ff8787` | `rgb(255,135,135)` |\n|   211   | `palevioletred1`    | `#ff87af` | `rgb(255,135,175)` |\n|   212   | `orchid2`           | `#ff87d7` | `rgb(255,135,215)` |\n|   213   | `orchid1`           | `#ff87ff` | `rgb(255,135,255)` |\n|   214   | `orange1`           | `#ffaf00` |  `rgb(255,175,0)`  |\n|   215   | `sandybrown`        | `#ffaf5f` | `rgb(255,175,95)`  |\n|   216   | `lightsalmon1`      | `#ffaf87` | `rgb(255,175,135)` |\n|   217   | `lightpink1`        | `#ffafaf` | `rgb(255,175,175)` |\n|   218   | `pink1`             | `#ffafd7` | `rgb(255,175,215)` |\n|   219   | `plum1`             | `#ffafff` | `rgb(255,175,255)` |\n|   220   | `gold1`             | `#ffd700` |  `rgb(255,215,0)`  |\n|   222   | `lightgoldenrod2`   | `#ffd787` | `rgb(255,215,135)` |\n|   223   | `navajowhite1`      | `#ffd7af` | `rgb(255,215,175)` |\n|   224   | `mistyrose1`        | `#ffd7d7` | `rgb(255,215,215)` |\n|   225   | `thistle1`          | `#ffd7ff` | `rgb(255,215,255)` |\n|   226   | `yellow1`           | `#ffff00` |  `rgb(255,255,0)`  |\n|   227   | `lightgoldenrod1`   | `#ffff5f` | `rgb(255,255,95)`  |\n|   228   | `khaki1`            | `#ffff87` | `rgb(255,255,135)` |\n|   229   | `wheat1`            | `#ffffaf` | `rgb(255,255,175)` |\n|   230   | `cornsilk1`         | `#ffffd7` | `rgb(255,255,215)` |\n|   231   | `grey100`           | `#ffffff` | `rgb(255,255,255)` |\n|   232   | `grey3`             | `#080808` |    `rgb(8,8,8)`    |\n|   233   | `grey7`             | `#121212` |  `rgb(18,18,18)`   |\n|   234   | `grey11`            | `#1c1c1c` |  `rgb(28,28,28)`   |\n|   235   | `grey15`            | `#262626` |  `rgb(38,38,38)`   |\n|   236   | `grey19`            | `#303030` |  `rgb(48,48,48)`   |\n|   237   | `grey23`            | `#3a3a3a` |  `rgb(58,58,58)`   |\n|   238   | `grey27`            | `#444444` |  `rgb(68,68,68)`   |\n|   239   | `grey30`            | `#4e4e4e` |  `rgb(78,78,78)`   |\n|   240   | `grey35`            | `#585858` |  `rgb(88,88,88)`   |\n|   241   | `grey39`            | `#626262` |  `rgb(98,98,98)`   |\n|   242   | `grey42`            | `#6c6c6c` | `rgb(108,108,108)` |\n|   243   | `grey46`            | `#767676` | `rgb(118,118,118)` |\n|   244   | `grey50`            | `#808080` | `rgb(128,128,128)` |\n|   245   | `grey54`            | `#8a8a8a` | `rgb(138,138,138)` |\n|   246   | `grey58`            | `#949494` | `rgb(148,148,148)` |\n|   247   | `grey62`            | `#9e9e9e` | `rgb(158,158,158)` |\n|   248   | `grey66`            | `#a8a8a8` | `rgb(168,168,168)` |\n|   249   | `grey70`            | `#b2b2b2` | `rgb(178,178,178)` |\n|   250   | `grey74`            | `#bcbcbc` | `rgb(188,188,188)` |\n|   251   | `grey78`            | `#c6c6c6` | `rgb(198,198,198)` |\n|   252   | `grey82`            | `#d0d0d0` | `rgb(208,208,208)` |\n|   253   | `grey85`            | `#dadada` | `rgb(218,218,218)` |\n|   254   | `grey89`            | `#e4e4e4` | `rgb(228,228,228)` |\n|   255   | `grey93`            | `#eeeeee` | `rgb(238,238,238)` |\n\n</details>\n\n## Development\n\n**PRs welcome!**\n\nShowcase your configuration!\nSubmit a PR with your configuration and a screenshot.\n\n### Installation\n\n1. Install [Poetry](https://python-poetry.org/docs/)\n1. Clone or fork the repo\n1. Install the dependencies\n   `poetry install`\n   _This creates a virtual environment and installs the project into it._\n1. Activate the virtual environment\n   `poetry shell`\n1. Run the project\n   `pihello ...`\n\n### TODO-list\n\n_In no particular order_\n\n- ~~Authentication for access to more variables~~\n- Start accessing more variables\n- Justification styling similar to Python\'s `ljust()` and `rjust()`\n- Use the screen width and height to break up the text\n- Add actual support for indentation\n- Conditional formatting/styling\n- Periodic updates (as if using `watch` command) but with [working colors](https://stackoverflow.com/questions/3793126/colors-with-unix-command-watch#3794222)\n- Structured config using `.yaml` or some other type\n\n### Changelog\n\nChangelog can be found in [CHANGELOG.md](docs/CHANGELOG.md)\n\n## Licence\n\n[MIT Licence](./LICENCE)\n',
    'author': 'pavelgar',
    'author_email': 'pavel.garmuyev@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/pavelgar/Pi-hello',
    'packages': packages,
    'package_data': package_data,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
